@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 
+import sys
 import html5lib
 
 try:
@@ -186,7 +187,13 @@ def _text(e):
 
 if __name__ == "__main__":
     import sys, urllib
-    url = sys.argv[1]
-    for item in get_items(urllib.urlopen(url)):
-        print item.json()
-        print
+    if len(sys.argv) < 2:
+        print "Usage: %s URL [...]" % sys.argv[0]
+        sys.exit(1)
+
+    for url in sys.argv[1:]:
+        sys.stderr.write(url + "\n")
+
+        for item in get_items(urllib.urlopen(url)):
+            print item.json()
+            print
